@@ -2,6 +2,7 @@
 
 use std::{convert::TryInto, mem::size_of};
 
+use solana_program::program_option::COption;
 use solana_program::{
     instruction::{AccountMeta, Instruction},
     msg,
@@ -9,7 +10,6 @@ use solana_program::{
     pubkey::{Pubkey, PUBKEY_BYTES},
     sysvar,
 };
-use solana_program::program_option::COption;
 
 use crate::error::LendingError;
 
@@ -583,7 +583,10 @@ pub fn deposit_obligation_collateral(
     {
         accounts.push(AccountMeta::new(staking_account_pubkey, false));
         accounts.push(AccountMeta::new(staking_pool_pubkey, false));
-        accounts.push(AccountMeta::new_readonly(port_staking_instructions::id(), false));
+        accounts.push(AccountMeta::new_readonly(
+            port_staking_instructions::id(),
+            false,
+        ));
     }
     Instruction {
         program_id,
@@ -627,7 +630,10 @@ pub fn withdraw_obligation_collateral(
     {
         accounts.push(AccountMeta::new(staking_account_pubkey, false));
         accounts.push(AccountMeta::new(staking_pool_pubkey, false));
-        accounts.push(AccountMeta::new_readonly(port_staking_instructions::id(), false));
+        accounts.push(AccountMeta::new_readonly(
+            port_staking_instructions::id(),
+            false,
+        ));
     }
     Instruction {
         program_id,
@@ -743,7 +749,10 @@ pub fn liquidate_obligation(
     ] {
         accounts.push(AccountMeta::new(staking_account_pubkey, false));
         accounts.push(AccountMeta::new(staking_pool_pubkey, false));
-        accounts.push(AccountMeta::new_readonly(port_staking_instructions::id(), false));
+        accounts.push(AccountMeta::new_readonly(
+            port_staking_instructions::id(),
+            false,
+        ));
     }
     Instruction {
         program_id,
@@ -821,7 +830,7 @@ pub fn deposit_reserve_liquidity_and_obligation_collateral(
         AccountMeta::new_readonly(lending_market_authority_pubkey, false),
         AccountMeta::new(destination_deposit_collateral_pubkey, false),
         AccountMeta::new(obligation_pubkey, false),
-        AccountMeta::new(obligation_owner_pubkey, true),
+        AccountMeta::new_readonly(obligation_owner_pubkey, true),
         AccountMeta::new_readonly(user_transfer_authority_pubkey, true),
         AccountMeta::new_readonly(sysvar::clock::id(), false),
         AccountMeta::new_readonly(spl_token::id(), false),
@@ -831,7 +840,10 @@ pub fn deposit_reserve_liquidity_and_obligation_collateral(
     {
         accounts.push(AccountMeta::new(staking_account_pubkey, false));
         accounts.push(AccountMeta::new(staking_pool_pubkey, false));
-        accounts.push(AccountMeta::new_readonly(port_staking_instructions::id(), false));
+        accounts.push(AccountMeta::new_readonly(
+            port_staking_instructions::id(),
+            false,
+        ));
     }
     Instruction {
         program_id,
