@@ -16,7 +16,7 @@ pub use lending_market::*;
 pub use obligation::*;
 pub use reserve::*;
 
-use crate::math::{Decimal, WAD};
+use solana_maths::{Decimal, WAD};
 
 mod last_update;
 mod lending_market;
