@@ -3,7 +3,9 @@ use std::{
     u64,
 };
 
+use crate::error::LendingError;
 use arrayref::{array_mut_ref, array_ref, array_refs, mut_array_refs};
+use solana_maths::{Decimal, Rate, TryAdd, TryDiv, TryMul, TrySub};
 use solana_program::program_option::COption;
 use solana_program::{
     clock::Slot,
@@ -14,11 +16,6 @@ use solana_program::{
     pubkey::{Pubkey, PUBKEY_BYTES},
 };
 
-use crate::{
-    error::LendingError,
-    math::{Decimal, Rate, TryAdd, TryDiv, TryMul, TrySub},
-};
-
 use super::*;
 
 /// Percentage of an obligation that can be repaid during each liquidation call
